@@ -3,7 +3,7 @@
 #define MAX_ARG           0
 #define MAX_CALLBACK 10
 #define CALLBACK_TYPES 8
-#define USE_INLINE_ASM
+#define USE_DLSTACK
 #define WITH_TYPE_CHAR
 #define WITH_TYPE_SHORT
 #define WITH_TYPE_LONG
