@@ -3,14 +3,14 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module Config
-  RUBY_VERSION == "1.8.1" or
-    raise "ruby lib version (1.8.1) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.8.2" or
+    raise "ruby lib version (1.8.2) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.8/i386\-mingw32\Z', '')
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["srcdir"] = "/pub/ruby/18/dist/ruby-1.8.1/ruby"
+  CONFIG["srcdir"] = "/pub/ruby/18/dist/ruby-1.8.2/ruby"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -43,7 +43,7 @@ module Config
   CONFIG["LIBS"] = "-lwsock32 "
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "8"
-  CONFIG["TEENY"] = "1"
+  CONFIG["TEENY"] = "2"
   CONFIG["build"] = "i586-pc-linux-gnu"
   CONFIG["build_cpu"] = "i586"
   CONFIG["build_vendor"] = "pc"
@@ -91,14 +91,16 @@ module Config
   CONFIG["DLEXT2"] = "dll"
   CONFIG["LIBEXT"] = "a"
   CONFIG["LINK_SO"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
+  CONFIG["LIBPATHFLAG"] = " -L\"%s\""
   CONFIG["RPATHFLAG"] = ""
+  CONFIG["TRY_LINK"] = ""
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.1/m.obj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.2/m.obj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["ARCHFILE"] = ""
+  CONFIG["RDOCTARGET"] = ""
   CONFIG["XCFLAGS"] = ""
   CONFIG["XLDFLAGS"] = " -Wl,--stack,0x02000000 -L."
   CONFIG["LIBRUBY_LDSHARED"] = "gcc -mno-cygwin -shared -s"
@@ -126,7 +128,7 @@ module Config
   CONFIG["arch"] = "i386-mingw32"
   CONFIG["sitearch"] = "i386-msvcrt"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "'--cache=config.cache' '--program-prefix=' '--target=i386-mingw32' '--host=i686-pc-cygwin' '--build=i586-pc-linux-gnu' '--includedir=/usr/local/mingw/include' '--enable-shared' '--enable-tcltk_stubs' '--with-tcllib=tclstub84' '--with-tklib=tkstub84' '--with-dbm-type=gdbm' '--with-opt-dir=/usr/local/mingw' '--with-gcc=gcc -mno-cygwin' 'CXX=g++ -mno-cygwin' 'CFLAGS=-Os' 'build_alias=i586-pc-linux-gnu' 'host_alias=i686-pc-cygwin' 'target_alias=i386-mingw32'"
+  CONFIG["configure_args"] = "'--cache=config.cache' '--program-prefix=' '--target=i386-mingw32' '--host=i686-pc-cygwin' '--build=i586-pc-linux-gnu' '--includedir=/usr/local/mingw/include' '--enable-shared' '--disable-tcl-thread' '--enable-tcltk_stubs' '--with-tcllib=tclstub84' '--with-tklib=tkstub84' '--with-dbm-type=gdbm' '--with-opt-dir=/usr/local/mingw' '--with-gcc=gcc -mno-cygwin' '--with-bundled-md5' 'CXX=g++ -mno-cygwin' 'CFLAGS=-Os' 'build_alias=i586-pc-linux-gnu' 'host_alias=i686-pc-cygwin' 'target_alias=i386-mingw32'"
   CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["LTLIBOBJS"] = " fileblocks$(U).lo crypt$(U).lo flock$(U).lo acosh$(U).lo win32$(U).lo"
@@ -141,7 +143,7 @@ module Config
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
-  CONFIG["compile_dir"] = "/pub/ruby/18/dist/ruby-1.8.1/m.obj"
+  CONFIG["compile_dir"] = "/pub/ruby/18/dist/ruby-1.8.2/m.obj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val, config = CONFIG)
